# Fast Vindex: A faster version of Dask's vindex for advanced indexing with arrays.

*fast-vindex* is a faster and more flexible alternative to Dask's built-in `vindex` function, designed to improve performance when working with complex or high-dimensional array indexing.

```{warning}
While `fast-vindex` aims to offer significant performance improvements over Dask’s built-in `vindex`, it does **not currently support all features** of the official implementation.

For a detailed list of supported indexing patterns and limitations, please refer to the [Supported Features](#supported-features) page.
```

**Useful links:** [Code Repository](https://gitlab.ifremer.fr/odatis-public/fast_vindex) | [Issues](https://gitlab.ifremer.fr/odatis-public/fast_vindex/issues)


```{toctree}
  :maxdepth: 1
  :hidden:

getting-started/index
examples/index
development/index
```
